@@ -18,7 +18,7 @@ use String::ShellQuote;
 
 use Params::Validate qw/validate/;
 our ( @EXPORT, @EXPORT_OK, %EXPORT_TAGS );
-our $VERSION = '0.066'; # VERSION
+our $VERSION = '0.068'; # VERSION
 
 @EXPORT      = qw();
 %EXPORT_TAGS = ();
@@ -47,10 +47,10 @@ sub makeblastdb {
 
     my $tmp_f = mktemp( catfile( $c{wd}, 'tempXXXXXX' ) );
 
-    if ( $type eq 'gz' ) {
-      system("gzip -dc $seqf >$tmp_f") == 0 or die "system failed: $?";
-    } elsif ( $type eq 'bz2' ) {
-      system("bzip2 -dc $seqf >$tmp_f") == 0 or die "system failed: $?";
+    if ( $type eq 'gzip' or $type eq 'bgzf' ) {
+      system("gzip -dc <$seqf >$tmp_f") == 0 or die "system failed: $?";
+    } elsif ( $type eq 'bzip2' ) {
+      system("bzip2 -dc <$seqf >$tmp_f") == 0 or die "system failed: $?";
     } else {
       confess("archive type $type not supported");
     }
